# deluca-lung

## Getting started
Instructions to provide to students: run the following commands
```
pip install deluca-lung
jupyter notebook
```

Navigate to the notebook `demo/2021-07-18 controller demo.ipynb` and run the cells.

## Setting up Raspberry Pi
- Create a Raspberry Pi OS image via [this](https://github.com/MinRegret/rpi-gadget-image-creator)
